# Command Line habit tracker

# IMPORTANT - Temporarily:
- Get a token from Hugging face: `<token>`
    - Navigate to: https://huggingface.co/settings/tokens
    - Sign up
    - Verify email
    - Add token - Choose token type: `read`
    - Save your token somewhere safe
- Define an environment variable:
    - Linux (Bash): `echo 'export HUGGING_FACE_TOKEN="<token>"' >> ~/.bashrc; source ~/.bashrc`
    - Windows (Command Prompt): `setx HUGGING_FACE_TOKEN "<token>"`

# Downloading:
- open command line (Prompt on windows / Terminal on Linux)
- run `pip install cmd-habit-tracker`

# Running the app
- open command line (Prompt on windows / Terminal on Linux)
- run `habits`

# DOCUMENTATION
- You can ask the app itself how to use it
- Start the app by running `habits`
- Run the command `docs`
- Ask a question

# HELP
- To see all possible commands run `help` after starting the program

